@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXgeneral.c,v 8.11 1997/10/22 08:07:44 markd Exp $
+ * $Id: tclXgeneral.c,v 8.11.2.1 1998/09/28 19:01:28 markd Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -234,6 +234,14 @@ TclX_InfoxObjCmd (clientData, interp, objc, objv)
         Tcl_SetBooleanObj (resultPtr, TRUE);
 #       else
         Tcl_SetBooleanObj (resultPtr, FALSE);
+#       endif        
+        return TCL_OK;
+    }
+    if (STREQU ("have_signal_restart", optionPtr)) {
+#       ifndef NO_SIG_RESTART
+        Tcl_SetBooleanObj (resultPtr, TRUE);
+#       else
+        Tcl_SetBooleanObj (resultPtr, FALSE);
 #       endif        
         return TCL_OK;
     }
