@@ -3,7 +3,7 @@
  *
  * Mathematical Tcl commands.
  *-----------------------------------------------------------------------------
- * Copyright 1991-1996 Karl Lehenbauer and Mark Diekhans.
+ * Copyright 1991-1997 Karl Lehenbauer and Mark Diekhans.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted, provided
@@ -12,37 +12,63 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXmath.c,v 7.0 1996/06/16 05:30:38 markd Exp $
+ * $Id: tclXmath.c,v 8.6 1997/07/04 20:23:56 markd Exp $
  *-----------------------------------------------------------------------------
  */
 
 #include "tclExtdInt.h"
 
-/*
- * Define return of random function unless stdlib does it.  If we are using
- * out own version, make sure to define it.
- */
-#if defined(NO_RANDOM) || defined(NO_RANDOM_PROTO)
-long random ();
+#ifndef tclx_random
+#  define tclx_srandom srandom
+#  define tclx_random random
 #endif
 
 /*
  * Prototypes of internal functions.
  */
 static int
-ConvertIntOrDouble _ANSI_ARGS_((Tcl_Interp *interp,
-                                char       *numStr,
-                                double     *valuePtr));
+ConvertIntOrDoubleObj _ANSI_ARGS_((Tcl_Interp *interp,
+                                   Tcl_Obj    *numStrObj,
+                                   double     *valuePtr));
 
 static long 
 ReallyRandom _ANSI_ARGS_((long my_range));
 
+static int
+TclX_MaxObjCmd _ANSI_ARGS_((ClientData  clientData,
+                            Tcl_Interp *interp,
+                            int         objc,
+                            Tcl_Obj   *CONST objv[]));
+
+static int
+TclX_MinObjCmd _ANSI_ARGS_((ClientData  clientData,
+                            Tcl_Interp *interp,
+                            int         objc,
+                            Tcl_Obj   *CONST objv[]));
+
+static int
+TclX_MaxFunc _ANSI_ARGS_((ClientData  clientData,
+                          Tcl_Interp *interp,
+                          Tcl_Value  *args,
+                          Tcl_Value  *resultPtr));
+
+static int
+TclX_MinFunc _ANSI_ARGS_((ClientData  clientData,
+                          Tcl_Interp *interp,
+                          Tcl_Value  *args,
+                          Tcl_Value  *resultPtr));
+
+static int
+TclX_RandomObjCmd _ANSI_ARGS_((ClientData  clientData,
+                               Tcl_Interp *interp,
+                               int         objc,
+                               Tcl_Obj   *CONST objv[]));
 
 
 /*-----------------------------------------------------------------------------
- * ConvertIntOrDouble --
+ * ConvertIntOrDoubleObj --
  *
- *   Convert a number that can be in any legal integer or floating point
+ *   Convert a number object that can be in any legal integer or floating point
  * format (including integer hex and octal specifications) to a double.
  *
  * Parameters:
@@ -54,25 +80,26 @@ ReallyRandom _ANSI_ARGS_((long my_range));
  *-----------------------------------------------------------------------------
  */
 static int
-ConvertIntOrDouble (interp, numStr, valuePtr)
+ConvertIntOrDoubleObj (interp, numStrObj, valuePtr)
     Tcl_Interp *interp;
-    char       *numStr;
+    Tcl_Obj    *numStrObj;
     double     *valuePtr;
 {
     long lvalue;
 
-    if (strpbrk (numStr, ".eE") != NULL) {
-        return Tcl_GetDouble (interp, numStr, valuePtr);
-    } else {
-        if (Tcl_GetLong (interp, numStr, &lvalue) != TCL_OK)
-            return TCL_ERROR;
-        *valuePtr = (double) lvalue;
-        return TCL_OK;
+    if (Tcl_GetLongFromObj (interp, numStrObj, &lvalue) == TCL_OK) {
+	*valuePtr = (double) lvalue;
+	return TCL_OK;
     }
+
+    if (Tcl_GetDoubleFromObj (interp, numStrObj, valuePtr) == TCL_OK)
+	return TCL_OK;
+
+    return TCL_ERROR;
 }
 
 /*-----------------------------------------------------------------------------
- * Tcl_MaxCmd --
+ * TclX_MaxObjCmd --
  *      Implements the Tcl max command:
  *        max num1 ?..numN?
  *
@@ -81,35 +108,32 @@ ConvertIntOrDouble (interp, numStr, valuePtr)
  *-----------------------------------------------------------------------------
  */
 static int
-Tcl_MaxCmd (clientData, interp, argc, argv)
+TclX_MaxObjCmd (clientData, interp, objc, objv)
     ClientData  clientData;
     Tcl_Interp *interp;
-    int         argc;
-    char      **argv;
+    int         objc;
+    Tcl_Obj   *CONST objv[];
 {
     double value, maxValue = -MAXDOUBLE;
-    int idx, maxIdx   =  1;
+    int idx, maxIdx = 1;
 
-    if (argc < 2) {
-        Tcl_AppendResult (interp, tclXWrongArgs, argv [0], 
-                          " num1 ?..numN?", (char *) NULL);
-        return TCL_ERROR;
-    }
+    if (objc < 2)
+	return TclX_WrongArgs (interp, objv[0], "num1 ?..numN?");
 
-    for (idx = 1; idx < argc; idx++) {
-        if (ConvertIntOrDouble (interp, argv [idx], &value) != TCL_OK)
-            return TCL_ERROR;
+    for (idx = 1; idx < objc; idx++) {
+	if (ConvertIntOrDoubleObj (interp, objv [idx], &value) != TCL_OK)
+	    return TCL_ERROR;
         if (value > maxValue) {
             maxValue = value;
             maxIdx = idx;
         }
     }
-    strcpy (interp->result, argv [maxIdx]);
+    Tcl_SetObjResult (interp, objv [maxIdx]);
     return TCL_OK;
 }
 
 /*-----------------------------------------------------------------------------
- * Tcl_MinCmd --
+ * TclX_MinObjCmd --
  *     Implements the TCL min command:
  *         min num1 ?..numN?
  *
@@ -118,36 +142,33 @@ Tcl_MaxCmd (clientData, interp, argc, argv)
  *-----------------------------------------------------------------------------
  */
 static int
-Tcl_MinCmd (clientData, interp, argc, argv)
+TclX_MinObjCmd (clientData, interp, objc, objv)
     ClientData  clientData;
     Tcl_Interp *interp;
-    int     argc;
-    char      **argv;
+    int         objc;
+    Tcl_Obj   *CONST objv[];
 {
     double value, minValue = MAXDOUBLE;
     int idx, minIdx   = 1;
 
-    if (argc < 2) {
-        Tcl_AppendResult (interp, tclXWrongArgs, argv [0], 
-                          " num1 ?..numN?", (char *) NULL);
-        return TCL_ERROR;
-    }
+    if (objc < 2)
+	return TclX_WrongArgs (interp, objv[0], "num1 ?..numN?");
 
-    for (idx = 1; idx < argc; idx++) {
-        if (ConvertIntOrDouble (interp, argv [idx], &value) != TCL_OK)
+    for (idx = 1; idx < objc; idx++) {
+        if (ConvertIntOrDoubleObj (interp, objv [idx], &value) != TCL_OK)
             return TCL_ERROR;
         if (value < minValue) {
             minValue = value;
             minIdx = idx;
-            }
-        }
-    strcpy (interp->result, argv [minIdx]);
+	}
+    }
+    Tcl_SetObjResult (interp, objv [minIdx]);
     return TCL_OK;
 }
 
 /*-----------------------------------------------------------------------------
  *
- * Tcl_MaxFunc --
+ * TclX_MaxFunc --
  *      Implements the Tcl max math function
  *        expr max(num1, num2)
  *
@@ -157,7 +178,7 @@ Tcl_MinCmd (clientData, interp, argc, argv)
  *-----------------------------------------------------------------------------
  */
 static int
-Tcl_MaxFunc (clientData, interp, args, resultPtr)
+TclX_MaxFunc (clientData, interp, args, resultPtr)
     ClientData  clientData;
     Tcl_Interp *interp;
     Tcl_Value  *args;
@@ -192,7 +213,7 @@ Tcl_MaxFunc (clientData, interp, args, resultPtr)
 
 /*-----------------------------------------------------------------------------
  *
- * Tcl_MinFunc --
+ * TclX_MinFunc --
  *      Implements the Tcl min math function
  *        expr min(num1, num2)
  *
@@ -202,7 +223,7 @@ Tcl_MaxFunc (clientData, interp, args, resultPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-Tcl_MinFunc (clientData, interp, args, resultPtr)
+TclX_MinFunc (clientData, interp, args, resultPtr)
     ClientData  clientData;
     Tcl_Interp *interp;
     Tcl_Value  *args;
@@ -251,13 +272,13 @@ ReallyRandom (myRange)
 
     maxMultiple = RANDOM_RANGE / myRange;
     maxMultiple *= myRange;
-    while ((rnum = random ()) >= maxMultiple)
+    while ((rnum = tclx_random ()) >= maxMultiple)
         continue;
     return (rnum % myRange);
 }
 
 /*-----------------------------------------------------------------------------
- * Tcl_RandomCmd  --
+ * TclX_RandomObjCmd  --
  *     Implements the TCL random command:
  *     random limit | seed ?seedval?
  *
@@ -266,64 +287,65 @@ ReallyRandom (myRange)
  *-----------------------------------------------------------------------------
  */
 static int
-Tcl_RandomCmd (clientData, interp, argc, argv)
-    ClientData  clientData;
+TclX_RandomObjCmd (dummy, interp, objc, objv)
+    ClientData  dummy;
     Tcl_Interp *interp;
-    int         argc;
-    char      **argv;
+    int         objc;
+    Tcl_Obj   *CONST objv[];
 {
     long range;
+    char *seedString;
 
-    if ((argc < 2) || (argc > 3))
+    if ((objc < 2) || (objc > 3))
         goto invalidArgs;
 
-    if (STREQU (argv [1], "seed")) {
-        unsigned seed;
-
-        if (argc == 3) {
-            if (Tcl_GetUnsigned (interp, argv[2], &seed) != TCL_OK)
-                return TCL_ERROR;
-        } else
-            seed = (unsigned) (getpid() + time((time_t *)NULL));
-
-        srandom (seed);
-
-    } else {
-        if (argc != 2)
+    if (Tcl_GetLongFromObj ((Tcl_Interp *) NULL, objv [1], &range) == TCL_OK) {
+        if (objc != 2)
             goto invalidArgs;
-        if (Tcl_GetLong (interp, argv[1], &range) != TCL_OK)
-            return TCL_ERROR;
+
         if ((range <= 0) || (range > RANDOM_RANGE))
             goto outOfRange;
+    } else {
+        int seed;
 
-        sprintf (interp->result, "%ld", ReallyRandom (range));
+	seedString = Tcl_GetStringFromObj (objv [1], NULL);
+	if (!STREQU (seedString, "seed"))
+	    goto invalidArgs;
+
+	if (objc == 3) {
+	    if (Tcl_GetIntFromObj (interp, objv[2], &seed) != TCL_OK)
+		return TCL_ERROR;
+	} else {
+	    seed = (getpid () + time ((time_t *)NULL));
+	}
+	(void) tclx_srandom (seed);
+	return TCL_OK;
     }
+    Tcl_SetIntObj (Tcl_GetObjResult (interp), ReallyRandom (range));
     return TCL_OK;
 
   invalidArgs:
-    Tcl_AppendResult (interp, tclXWrongArgs, argv [0], 
-                      " limit | seed ?seedval?", (char *) NULL);
-    return TCL_ERROR;
+    return TclX_WrongArgs (interp, objv[0], "limit | seed ?seedval?");
 
   outOfRange:
     {
         char buf [18];
 
         sprintf (buf, "%ld", RANDOM_RANGE);
-        Tcl_AppendResult (interp, "range must be > 0 and <= ",
-                          buf, (char *) NULL);
+        TclX_AppendObjResult (interp, " range must be > 0 and <= ", buf,
+                              (char *) NULL);
         return TCL_ERROR;
     }
 }
 
 /*-----------------------------------------------------------------------------
- *  Tcl_InitMath --
+ *  TclX_MathInit --
  *
  *    Initialize the TclX math commands and functions.
  *-----------------------------------------------------------------------------
  */
 void
-Tcl_InitMath (interp)
+TclX_MathInit (interp)
     Tcl_Interp *interp;
 {
     Tcl_ValueType minMaxArgTypes [2];
@@ -331,21 +353,38 @@ Tcl_InitMath (interp)
     minMaxArgTypes [0] = TCL_EITHER;
     minMaxArgTypes [1] = TCL_EITHER;
 
-    Tcl_CreateCommand (interp, "max", Tcl_MaxCmd,
-                       (ClientData) NULL, (void (*)()) NULL);
-    Tcl_CreateCommand (interp, "min", Tcl_MinCmd,
-                       (ClientData) NULL, (void (*)()) NULL);
-    Tcl_CreateCommand (interp, "random", Tcl_RandomCmd,
-                       (ClientData) NULL, (void (*)()) NULL);
+    Tcl_CreateObjCommand (interp, 
+			  "max",
+			  TclX_MaxObjCmd,
+                          (ClientData) NULL,
+			  (Tcl_CmdDeleteProc*) NULL);
 
-    Tcl_CreateMathFunc (interp, "max",
-                        2, minMaxArgTypes,
-                        Tcl_MaxFunc,
+    Tcl_CreateObjCommand (interp,
+			  "min",
+			  TclX_MinObjCmd,
+                          (ClientData) NULL,
+			  (Tcl_CmdDeleteProc*) NULL);
+
+    Tcl_CreateObjCommand (interp,
+                          "random",
+			  TclX_RandomObjCmd,
+                          (ClientData) NULL,
+			  (Tcl_CmdDeleteProc*) NULL);
+
+    Tcl_CreateMathFunc (interp,
+                        "max",
+                        2, 
+			minMaxArgTypes,
+                        TclX_MaxFunc,
                         (ClientData) NULL);
 
-    Tcl_CreateMathFunc (interp, "min",
-                        2, minMaxArgTypes,
-                        Tcl_MinFunc,
+    Tcl_CreateMathFunc (interp, 
+			"min",
+                        2, 
+			minMaxArgTypes,
+                        TclX_MinFunc,
                         (ClientData) NULL);
 
 }
+
+
